@@ -3,15 +3,15 @@ Term::ReadLine::Tiny::Constants;
 
 use warnings;
 use strict;
-use 5.010000;
+use 5.008000;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use Exporter qw( import );
 
 our @EXPORT_OK = qw(
         NEXT_get_key
-        CONTROL_A CONTROL_B CONTROL_D CONTROL_E CONTROL_F CONTROL_H CONTROL_U KEY_BTAB KEY_TAB
+        CONTROL_A CONTROL_B CONTROL_D CONTROL_E CONTROL_F CONTROL_H CONTROL_K CONTROL_U KEY_BTAB KEY_TAB
         KEY_ENTER KEY_ESC KEY_BSPACE
         VK_CODE_END VK_CODE_HOME VK_CODE_LEFT VK_CODE_UP VK_CODE_RIGHT VK_CODE_DELETE
         VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DELETE
@@ -20,7 +20,7 @@ our @EXPORT_OK = qw(
 our %EXPORT_TAGS = (
     rl => [ qw(
         NEXT_get_key
-        CONTROL_A CONTROL_B CONTROL_D CONTROL_E CONTROL_F CONTROL_H CONTROL_U KEY_BTAB KEY_TAB
+        CONTROL_A CONTROL_B CONTROL_D CONTROL_E CONTROL_F CONTROL_H CONTROL_K CONTROL_U KEY_BTAB KEY_TAB
         KEY_ENTER KEY_ESC KEY_BSPACE
         VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DELETE
     ) ],
@@ -65,6 +65,7 @@ sub CONTROL_F  () { 0x06 }
 sub CONTROL_H  () { 0x08 }
 sub KEY_BTAB   () { 0x08 }
 sub KEY_TAB    () { 0x09 }
+sub CONTROL_K  () { 0x0b }
 sub KEY_ENTER  () { 0x0d }
 sub CONTROL_U  () { 0x15 }
 sub KEY_ESC    () { 0x1b }
